@@ -46,8 +46,9 @@ case ${1} in
 
 	;;
 	livecd-update)
+		shift
 		# Now, finalize and tweak the livecd fs (inside of the chroot)
-		exec_in_chroot  ${clst_shdir}/support/livecdfs-update.sh
+		exec_in_chroot  ${clst_shdir}/support/livecdfs-update.sh ${@}
 	;;
 
 	bootloader)
@@ -55,12 +56,12 @@ case ${1} in
 		# Here is where we poke in our identifier
 		touch ${1}/livecd
 
-		${clst_shdir}/support/bootloader-setup.sh ${1}
+		${clst_shdir}/support/iso-bootloader-setup.sh ${1}
 	;;
 
 	iso)
 		shift
-		${clst_shdir}/support/create-iso.sh ${1}
+		${clst_shdir}/support/create-iso.sh ${@}
 	;;
 
 	clean)
