@@ -37,10 +37,8 @@ if [ -n "${clst_update_seed}" ]; then
 		echo "Updating seed stage..."
 		if [ -n "${clst_update_seed_command}" ]; then
 			ROOT=/ run_merge --buildpkg=n "${clst_update_seed_command}"
-		elif grep -q '^\[changed-subslot\]' /usr/share/portage/config/sets/portage.conf; then
-			ROOT=/ run_merge --ignore-built-slot-operator-deps y @changed-subslot
 		else
-			ROOT=/ run_merge --update --deep --newuse --complete-graph --rebuild-if-new-ver gcc
+			ROOT=/ run_merge --buildpkg=n --update --deep --newuse @world
 		fi
 	elif [ "${clst_update_seed}" != "no" ]; then
 		echo "Invalid setting for update_seed: ${clst_update_seed}"
@@ -67,7 +65,7 @@ sed -i "/USE=\"${USE} build\"/d" ${clst_make_conf}
 
 echo "$locales" > /etc/locale.gen
 for etc in /etc "$ROOT"/etc; do
-	echo "LANG=C.UTF8" > ${etc}/env.d/02locale
+	echo "LANG=C.UTF-8" > ${etc}/env.d/02locale
 done
 update_env_settings
 
